==> invenio-rdm-records-0.31.2.tar.gz: invenio-rdm-records-0.31.2/invenio_rdm_records/records/api.py <==
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020 CERN.
# Copyright (C) 2021 TU Wien.
#
# Invenio-RDM-Records is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""RDM Record and Draft API."""

from invenio_drafts_resources.records import Draft, Record
from invenio_drafts_resources.records.api import \
    ParentRecord as ParentRecordBase
from invenio_pidstore.models import PIDStatus
from invenio_records.dumpers import ElasticsearchDumper
from invenio_records.dumpers.relations import RelationDumperExt
from invenio_records.systemfields import ConstantField, DictField, \
    ModelField, RelationsField
from invenio_records_resources.records.api import FileRecord
from invenio_records_resources.records.systemfields import FilesField, \
    IndexField, PIDListRelation, PIDRelation, PIDStatusCheckField
from invenio_vocabularies.records.api import Vocabulary
from werkzeug.local import LocalProxy

from . import models
from .dumpers import EDTFDumperExt, EDTFListDumperExt, GrantTokensDumperExt
from .systemfields import HasDraftCheckField, ParentRecordAccessField, \
    RecordAccessField


#
# Parent record API
#
class RDMParent(ParentRecordBase):
    """Example parent record."""

    # Configuration
    model_cls = models.RDMParentMetadata

    dumper = ElasticsearchDumper(
        extensions=[
            GrantTokensDumperExt("access.grant_tokens"),
        ]
    )

    # System fields
    schema = ConstantField(
        '$schema', 'local://records/parent-v1.0.0.json')

    access = ParentRecordAccessField()


#
# Common properties between records and drafts.
#
class CommonFieldsMixin:
    """Common system fields between records and drafts."""

    versions_model_cls = models.RDMVersionsState
    parent_record_cls = RDMParent

    schema = ConstantField(
       '$schema', 'local://records/record-v4.0.0.json')

    dumper = ElasticsearchDumper(
        extensions=[
            EDTFDumperExt('metadata.publication_date'),
            EDTFListDumperExt("metadata.dates", "date"),
            RelationDumperExt('relations'),
        ]
    )

    relations = RelationsField(
        languages=PIDListRelation(
            'metadata.languages',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('languages'),
            cache_key='languages',
        ),
        resource_type=PIDRelation(
            'metadata.resource_type',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('resource_types'),
            cache_key='resource_type',
        ),
        subjects=PIDListRelation(
            'metadata.subjects',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('subjects'),
            cache_key='subjects',
        ),
    )

    bucket_id = ModelField(dump=False)

    bucket = ModelField(dump=False)

    access = RecordAccessField()

    is_published = PIDStatusCheckField(status=PIDStatus.REGISTERED, dump=True)

    pids = DictField("pids")


#
# Draft API
#
class RDMFileDraft(FileRecord):
    """File associated with a draft."""

    model_cls = models.RDMFileDraftMetadata
    record_cls = LocalProxy(lambda: RDMDraft)


class RDMDraft(CommonFieldsMixin, Draft):
    """RDM draft API."""

    model_cls = models.RDMDraftMetadata

    index = IndexField(
        "rdmrecords-drafts-draft-v4.0.0", search_alias="rdmrecords"
    )

    files = FilesField(
        store=False,
        file_cls=RDMFileDraft,
        # Don't delete, we'll manage in the service
        delete=False,
    )

    has_draft = HasDraftCheckField()


#
# Record API
#
class RDMFileRecord(FileRecord):
    """Example record file API."""

    model_cls = models.RDMFileRecordMetadata
    record_cls = LocalProxy(lambda: RDMRecord)


class RDMRecord(CommonFieldsMixin, Record):
    """RDM Record API."""

    model_cls = models.RDMRecordMetadata

    index = IndexField(
        "rdmrecords-records-record-v4.0.0", search_alias="rdmrecords-records"
    )

    files = FilesField(
        store=False,
        file_cls=RDMFileRecord,
        # Don't create
        create=False,
        # Don't delete, we'll manage in the service
        delete=False,
    )

    has_draft = HasDraftCheckField(RDMDraft)

==> invenio-rdm-records-0.31.7.tar.gz: invenio-rdm-records-0.31.7/invenio_rdm_records/records/api.py <==
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020 CERN.
# Copyright (C) 2021 TU Wien.
#
# Invenio-RDM-Records is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""RDM Record and Draft API."""

from invenio_drafts_resources.records import Draft, Record
from invenio_drafts_resources.records.api import \
    ParentRecord as ParentRecordBase
from invenio_pidstore.models import PIDStatus
from invenio_records.dumpers import ElasticsearchDumper
from invenio_records.dumpers.relations import RelationDumperExt
from invenio_records.systemfields import ConstantField, DictField, \
    ModelField, RelationsField
from invenio_records_resources.records.api import FileRecord
from invenio_records_resources.records.systemfields import FilesField, \
    IndexField, PIDListRelation, PIDNestedListRelation, PIDRelation, \
    PIDStatusCheckField
from invenio_vocabularies.contrib.affiliations.api import Affiliations
from invenio_vocabularies.records.api import Vocabulary
from werkzeug.local import LocalProxy

from . import models
from .dumpers import EDTFDumperExt, EDTFListDumperExt, GrantTokensDumperExt
from .systemfields import HasDraftCheckField, ParentRecordAccessField, \
    RecordAccessField


#
# Parent record API
#
class RDMParent(ParentRecordBase):
    """Example parent record."""

    # Configuration
    model_cls = models.RDMParentMetadata

    dumper = ElasticsearchDumper(
        extensions=[
            GrantTokensDumperExt("access.grant_tokens"),
        ]
    )

    # System fields
    schema = ConstantField(
        '$schema', 'local://records/parent-v1.0.0.json')

    access = ParentRecordAccessField()


#
# Common properties between records and drafts.
#
class CommonFieldsMixin:
    """Common system fields between records and drafts."""

    versions_model_cls = models.RDMVersionsState
    parent_record_cls = RDMParent

    schema = ConstantField(
       '$schema', 'local://records/record-v4.0.0.json')

    dumper = ElasticsearchDumper(
        extensions=[
            EDTFDumperExt('metadata.publication_date'),
            EDTFListDumperExt("metadata.dates", "date"),
            RelationDumperExt('relations'),
        ]
    )

    relations = RelationsField(
        creator_affiliations=PIDNestedListRelation(
            'metadata.creators',
            relation_field='affiliations',
            attrs=['id', 'name'],
            pid_field=Affiliations.pid,
            cache_key='affiliations',
        ),
        contributor_affiliations=PIDNestedListRelation(
            'metadata.contributors',
            relation_field='affiliations',
            attrs=['id', 'name'],
            pid_field=Affiliations.pid,
            cache_key='affiliations',
        ),
        languages=PIDListRelation(
            'metadata.languages',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('languages'),
            cache_key='languages',
        ),
        resource_type=PIDRelation(
            'metadata.resource_type',
            attrs=['id', 'title', 'props.type', 'props.subtype'],
            pid_field=Vocabulary.pid.with_type_ctx('resourcetypes'),
            cache_key='resource_type',
        ),
        subjects=PIDListRelation(
            'metadata.subjects',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('subjects'),
            cache_key='subjects',
        ),
        related_identifiers=PIDListRelation(
            'metadata.related_identifiers',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('resourcetypes'),
            cache_key='resource_type',
            relation_field='resource_type'
        ),
        title_types=PIDListRelation(
            'metadata.additional_titles',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('titletypes'),
            cache_key='title_type',
            relation_field='type',
        ),
        title_languages=PIDListRelation(
            'metadata.additional_titles',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('languages'),
            cache_key='languages',
            relation_field='lang',
        ),
        creators_role=PIDListRelation(
            'metadata.creators',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('creatorsroles'),
            cache_key='role',
            relation_field='role'
        ),
        contributors_role=PIDListRelation(
            'metadata.contributors',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('contributorsroles'),
            cache_key='role',
            relation_field='role'
        ),
        description_type=PIDListRelation(
            'metadata.additional_descriptions',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('descriptiontypes'),
            cache_key='description_type',
            relation_field='type',
        ),
        description_languages=PIDListRelation(
            'metadata.additional_descriptions',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('languages'),
            cache_key='languages',
            relation_field='lang',
        ),
        date_types=PIDListRelation(
            'metadata.dates',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('datetypes'),
            cache_key='date_types',
            relation_field='type',
        ),
        relation_types=PIDListRelation(
            'metadata.related_identifiers',
            attrs=['id', 'title'],
            pid_field=Vocabulary.pid.with_type_ctx('relationtypes'),
            cache_key='relation_types',
            relation_field='relation_type',
        ),
    )

    bucket_id = ModelField(dump=False)

    bucket = ModelField(dump=False)

    access = RecordAccessField()

    is_published = PIDStatusCheckField(status=PIDStatus.REGISTERED, dump=True)

    pids = DictField("pids")


#
# Draft API
#
class RDMFileDraft(FileRecord):
    """File associated with a draft."""

    model_cls = models.RDMFileDraftMetadata
    record_cls = LocalProxy(lambda: RDMDraft)


class RDMDraft(CommonFieldsMixin, Draft):
    """RDM draft API."""

    model_cls = models.RDMDraftMetadata

    index = IndexField(
        "rdmrecords-drafts-draft-v4.0.0", search_alias="rdmrecords"
    )

    files = FilesField(
        store=False,
        file_cls=RDMFileDraft,
        # Don't delete, we'll manage in the service
        delete=False,
    )

    has_draft = HasDraftCheckField()


#
# Record API
#
class RDMFileRecord(FileRecord):
    """Example record file API."""

    model_cls = models.RDMFileRecordMetadata
    record_cls = LocalProxy(lambda: RDMRecord)


class RDMRecord(CommonFieldsMixin, Record):
    """RDM Record API."""

    model_cls = models.RDMRecordMetadata

    index = IndexField(
        "rdmrecords-records-record-v4.0.0", search_alias="rdmrecords-records"
    )

    files = FilesField(
        store=False,
        file_cls=RDMFileRecord,
        # Don't create
        create=False,
        # Don't delete, we'll manage in the service
        delete=False,
    )

    has_draft = HasDraftCheckField(RDMDraft)
